/*

Copyright (C) 2002-2003, Jeffrey D. Argast.

The authors make NO WARRANTY or representation, either express or implied,
with respect to this software, its quality, accuracy, merchantability, or
fitness for a particular purpose.  This software is provided "AS IS", and you,
its user, assume the entire risk as to its quality and accuracy.

Permission is hereby granted to use, copy, modify, and distribute this
software or portions thereof for any purpose, without fee, subject to these
conditions:

(1) If any part of the source code is distributed, then this
statement must be included, with this copyright and no-warranty notice
unaltered.

(2) Permission for use of this software is granted only if the user accepts
full responsibility for any undesirable consequences; the authors accept
NO LIABILITY for damages of any kind.

*/

#import "EditSheetController.h"
#import "AppUtils.h"

@interface EditSheetController (PrivateMethods)

- (void) sheetDidEnd: (NSWindow*) sheet
		 returnCode: (int) returnCode
		 contextInfo: (void*) contextInfo;

@end

@implementation EditSheetController

- (id) init
{
    self = [super init];
    
    [NSBundle loadNibNamed:@"EditWindow" owner:self];
    
	// Make the window scrollable in both horiz and vert directions
	// thereby turning off text wrap
	NSTextContainer* textContainer = [fTextView textContainer];

    [textContainer setWidthTracksTextView:NO];
    [textContainer setHeightTracksTextView:NO];

    [fTextView setHorizontallyResizable:YES];
    [fTextView setVerticallyResizable:YES];

	NSView* clipView = [fTextView superview];
	NSScrollView* scrollView = (NSScrollView*) [clipView superview];
    [scrollView setHasHorizontalScroller:YES];
	
    return self;
}

- (void) showSheet:(id)sender
		 selector:(SEL)senderSelector
		 withContent:(NSString*)contentString
{
	[fTextView setString:contentString];
	
	fSender   = sender;
	fSelector = senderSelector;
	
/*
	[NSApp beginSheet:fWindow
		   modalForWindow:[NSApp mainWindow]
		   modalDelegate:self
		   didEndSelector:@selector(sheetDidEnd:returnCode:contextInfo:)
		   contextInfo:nil];
*/

	//[fWindow makeKeyAndOrderFront:self];
	
	// I switched to modal dialog because I wanted undo/redo and I don't
	// know how to make that work with sheets.
	int retCode = [NSApp runModalForWindow:fWindow];
	
	if ( retCode == NSRunStoppedResponse )
	{
		[fSender performSelector:fSelector withObject:[fTextView string]];
	}
}

- (IBAction) okayButton: (id) sender
{
	[fWindow orderOut:sender];
	[NSApp stopModal];
	
//	[NSApp endSheet:fWindow returnCode:1];
}

- (IBAction) cancelButton: (id) sender
{
	[fWindow orderOut:sender];
	[NSApp abortModal];
	
//	[NSApp endSheet:fWindow returnCode:0];
}

@end



@implementation EditSheetController (PrivateMethods)

- (void) sheetDidEnd: (NSWindow*) sheet
		 returnCode: (int) returnCode
		 contextInfo: (void*) contextInfo
{
	if ( returnCode == 1 )
	{
		[fSender performSelector:fSelector withObject:[fTextView string]];
	}
}

@end
